@@ -1,6 +1,6 @@
 /***************************************************************************
                              -------------------
-    cvs         : $Id: benchmark.cc,v 1.5 2005/01/21 15:43:59 cstim Exp $
+    cvs         : $Id: benchmark.cc,v 1.7 2007/12/11 16:41:50 cstim Exp $
     begin       : Sat Aug 10 2002
     copyright   : (C) 2003 by Christian Stimming
     email       : 
@@ -28,7 +28,9 @@
 #include <ktoblzcheck.h>
 #include <iostream>
 #include <fstream>
-#include <stdio.h>
+#include <cstdio>
+#include <cstdlib>
+#include <climits>
 #include <assert.h>
 
 using namespace std;
