@@ -1,6 +1,6 @@
 /***************************************************************************
                              -------------------
-    cvs         : $Id: ktoblzcheck.cc,v 1.14 2007/02/16 15:46:54 cstim Exp $
+    cvs         : $Id: ktoblzcheck.cc,v 1.18 2007/12/11 16:41:50 cstim Exp $
     begin       : Sat Aug 10 2002
     copyright   : (C) 2002 by Fabian Kaiser
     email       : fabian@openhbci.de
@@ -32,11 +32,13 @@
 # define PACKAGE "ktoblzcheck"
 #endif
 
-#include <stdio.h>
 #include <ktoblzcheck.h>
+
+#include <cassert>
+#include <cstdlib>
+#include <cstdio>
 #include <iostream>
 #include <fstream>
-#include <cassert>
 
 using namespace std;
 
@@ -163,7 +165,16 @@ int main(int argc, char **argv) {
    // installed data file
    AccountNumberCheck *check_ptr = 0;
    if (bankdataFile.empty())
+   {
       check_ptr = new AccountNumberCheck();
+      time_t mydate = time(NULL);//-24*3600*30*9;
+      if (!check_ptr->loadDataForDate(mydate))
+      {
+	 std::time_t x = check_ptr->closestValidData(mydate);
+	 std::cerr << PACKAGE ": Warning: The available bankdata is not valid today; closest available date with valid bankdata is: " << ctime(&x)
+		   << std::endl;
+      }
+   }
    else 
    {
       ifstream test(bankdataFile.c_str());
