@@ -1,6 +1,6 @@
 /***************************************************************************
                              -------------------
-    cvs         : $Id: algorithms.cc,v 1.17 2007/02/17 09:52:05 cstim Exp $
+    cvs         : $Id: algorithms.cc,v 1.21 2008/02/05 19:51:06 cstim Exp $
     begin       : Sat Aug 10 2002
     copyright   : (C) 2002 by Fabian Kaiser
     email       : fabian@openhbci.de
@@ -29,9 +29,11 @@
 #endif
 #include "algorithms.h"
 #include "binreloc.h"
+#include <cassert>
+#include <cstdio>
+#include <cstdlib> // for free(3)
 #include <fstream>
 #include <iostream>
-#include <assert.h>
 
 
 #if OS_WIN32
@@ -186,9 +188,9 @@ std::string accnum_getRegKey(const char *value_name)
 #endif // null
 
 
+#ifdef OS_WIN32
 static std::string accnum_get_prefix()
 {
-#ifdef OS_WIN32
    // Partial implementation of 
    // http://developer.gnome.org/doc/API/2.0/glib/glib-Windows-Compatibility-Functions.html#g-win32-get-package-installation-directory
    char ch_fn[MAX_PATH], *p;
@@ -208,10 +210,9 @@ static std::string accnum_get_prefix()
       *p = '\0';
 
    return std::string(ch_fn);
-#else // OS_WIN32
-   return "";
-#endif // OS_WIN32
 }
+#endif // OS_WIN32
+
 std::string algorithms_get_bankdata_dir()
 {
    std::string pkgdatadir;
@@ -255,8 +256,8 @@ bool algorithms_init_binreloc()
 // ////////////////////
 
 AccountNumberCheck::Result
-algo01(int modulus, int weight[10], bool crossfoot, 
-	   int checkIndex, int accountId[10]) {
+algo01(const int modulus, const int weight[10], const bool crossfoot, 
+	   const int checkIndex, const int accountId[10]) {
 
   int result = algo03(modulus, weight, crossfoot, accountId, 0, 9);
   //  cout << "res%mod: " << result << endl;
@@ -279,8 +280,8 @@ algo01(int modulus, int weight[10], bool crossfoot,
 // 04, 07, 14, 58, 85/a, A2/v2, B2/v1, B4/v2, C3/v2, C4/v2
 // For all of these methods modulus is usually 11 
 AccountNumberCheck::Result 
-algo02(int modulus, int weight[10], int checkIndex, int accountId[10],
-	int startAdd, int stopAdd) {
+algo02(const int modulus, const int weight[10], const int checkIndex, const int accountId[10],
+	const int startAdd, const int stopAdd) {
   int res[10];
 
   // mult the weight with the account id
@@ -304,8 +305,8 @@ algo02(int modulus, int weight[10], int checkIndex, int accountId[10],
 	return AccountNumberCheck::ERROR;
 }
 
-int algo03(int modulus, int weight[10], bool crossfoot, int accountId[10], 
-		   int startAdd, int stopAdd) {
+int algo03(const int modulus, const int weight[10], const bool crossfoot, const int accountId[10], 
+		   const int startAdd, const int stopAdd) {
   int res[10];
   // mult the weight with the account id
   multArray(accountId, weight, res);
@@ -322,8 +323,8 @@ int algo03(int modulus, int weight[10], bool crossfoot, int accountId[10],
   return result;
 }
 
-int algo03a(int weight[10], bool crossfoot, int accountId[10], 
-		   int startAdd, int stopAdd) {
+int algo03a(const int weight[10], const bool crossfoot, const int accountId[10], 
+		   const int startAdd, const int stopAdd) {
   int res[10];
   // same as algo03, but return result before modulus
   // mult the weight with the account id
@@ -340,8 +341,8 @@ int algo03a(int weight[10], bool crossfoot, int accountId[10],
 }
 
 // Algorithm used in methods 24 and B9 variant 1.
-int algo05(int modulus1, int modulus2, int weight[10], int accountId[10], 
-		   int startAdd, int stopAdd) {
+int algo05(const int modulus1, const int modulus2, const int weight[10], const int accountId[10], 
+		   const int startAdd, const int stopAdd) {
   int res[10];
   // mult the weight with the account id
   multArray(accountId, weight, res);
@@ -357,7 +358,7 @@ int algo05(int modulus1, int modulus2, int weight[10], int accountId[10],
 }
  
 AccountNumberCheck::Result
-algo06(const std::string& accountId) {
+algo06(const int accountId[10]) {
   int i = 0;
   int c2 = 0;
   int d2 = 0;
@@ -368,7 +369,10 @@ algo06(const std::string& accountId) {
   int tab1[5] = {0, 4, 3, 2, 6};
   int tab2[5] = {7, 1, 5, 9, 8};
 
-  number2Array(accountId, account);
+  // copy to keep interface array const
+  for(i=0; i<=9; i++) {
+    account[i] = accountId[i];
+  }
 
   i = 4;
   while (0 == account[i-1])
@@ -473,12 +477,15 @@ algo06(const std::string& accountId) {
 }
    
 AccountNumberCheck::Result 
-algo04(const std::string& bankId, std::string accountId) {
+algo04(const std::string& bankId, const std::string accountId) {
 
-  while (8 < accountId.length() && '0' == accountId[0])
-    accountId = accountId.substr(1);
+  // keep the interface argument constant
+  std::string	accountBuf	= accountId;
 
-  if (8 != accountId.length())
+  while (8 < accountBuf.length() && '0' == accountBuf[0])
+    accountBuf = accountBuf.substr(1);
+
+  if (8 != accountBuf.length())
 	return AccountNumberCheck::ERROR;
   if (5 > bankId.length())
 	return AccountNumberCheck::ERROR;
@@ -489,12 +496,12 @@ algo04(const std::string& bankId, std::string accountId) {
   // eser alt number
   string bankPart = bankId.substr(bankId.length() - 4);
 
-  string accountPart = accountId.substr(2);
+  string accountPart = accountBuf.substr(2);
   // strip leading '0's
   while (0 < accountPart.length() && '0' == accountPart[0])
     accountPart = accountPart.substr(1); 
 
-  string checkPart = accountId.substr(0, 2);
+  string checkPart = accountBuf.substr(0, 2);
   // backup the check number
   char checkNumber = checkPart[1];
   // the checknumber must not be used when multiplying -> set to 0 
@@ -547,12 +554,15 @@ algo04(const std::string& bankId, std::string accountId) {
 // same as algo04, but for nine digit accountIDs with
 // a little different eser12 system.
 AccountNumberCheck::Result 
-algo04a(const std::string& bankId, std::string accountId) {
+algo04a(const std::string& bankId, const std::string accountId) {
 
-  while (9 < accountId.length() && '0' == accountId[0])
-    accountId = accountId.substr(1);
+  // keep the interface argument constant
+  std::string	accountBuf	= accountId;
 
-  if (9 != accountId.length())
+  while (9 < accountBuf.length() && '0' == accountBuf[0])
+    accountBuf = accountBuf.substr(1);
+
+  if (9 != accountBuf.length())
 	return AccountNumberCheck::ERROR;
   if (5 > bankId.length())
 	return AccountNumberCheck::ERROR;
@@ -563,12 +573,12 @@ algo04a(const std::string& bankId, std::string accountId) {
             //bankPart = bankPart.substr(1);
   string bankPart2 = bankId.substr(bankId.length() - 1);
   // cout << "bankpart: " << bankPart << endl;
-  // the second digit of the accountid
-  string checkPart = accountId.substr(2, 1);
+  // the second digit of the accountBuf
+  string checkPart = accountBuf.substr(2, 1);
   // cout << "checkPart: " << checkPart << endl;
-  string accountPart1 = accountId.substr(0, 1);
-  string accountPart2 = accountId.substr(1, 1);
-  string accountPart = accountId.substr(3);
+  string accountPart1 = accountBuf.substr(0, 1);
+  string accountPart2 = accountBuf.substr(1, 1);
+  string accountPart = accountBuf.substr(3);
   // skip leading "0" in the the accountPart
   while (accountPart.length() > 0 && '0' == accountPart[0])
   	accountPart = accountPart.substr(1);
@@ -628,7 +638,7 @@ algo04a(const std::string& bankId, std::string accountId) {
 
 // iterated transformation
 AccountNumberCheck::Result 
-algo07(int accountId[10], int transform[6][10]) {
+algo07(const int accountId[10], const int transform[6][10]) {
   int result = 0;
   for (int i=0; i<10; i++) {
         result = result + transform[transform[5][i]][accountId[i]];
@@ -717,7 +727,7 @@ int add(const int *source, int start, int stop) {
     }
 }
 
-string array2Number(int a[10]) {
+string array2Number(const int a[10]) {
     string result("0000000000");
     for (unsigned i=0; i<10; i++) {
 	result[i] = '0' + a[i];
@@ -759,5 +769,3 @@ long_long number2LongLong(const string& number) {
 
   return result;
 }
-
-
